
import dbus
import unittest

from tests.utils import (
    kill_process,
    setup_test_env,
    start_dbus_daemon,
)
setup_test_env()

from softwarecenter.db.dataprovider import SoftwareCenterDataProvider



class DataProviderTestCase(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        cls.proc, dbus_address = start_dbus_daemon()
        cls.bus = dbus.bus.BusConnection(dbus_address)
        bus_name = dbus.service.BusName(
            'com.ubuntu.SoftwareCenterDataProvider', cls.bus)
        # get the provider
        cls.provider = SoftwareCenterDataProvider(bus_name)

    @classmethod
    def tearDownClass(cls):
        cls.provider.stop()
        kill_process(cls.proc)

    def test_have_data_in_db(self):
        self.assertTrue(len(self.provider.db) > 100)

    def test_get_details(self):
        result = self.provider.GetAppDetails("", "gedit")
        self.assertEqual(result["component"], "main")
        self.assertEqual(result["icon"], "accessories-text-editor")
        self.assertEqual(result["name"], "gedit")
        self.assertEqual(result["pkgname"], "gedit")
        self.assertEqual(result["price"], "Free")
        self.assertEqual(result["raw_price"], "")

if __name__ == "__main__":
    unittest.main()
